# synergos
set of tools to improve ML tasks in sklearn and tensorflow

## Installation

Run the following to install:
```bash
$ pip install synergos
```

## Usage

```python
from functions import say_hello

# Generate "Hello World!
say_hello()

# Generate "Hello Everybody"
say_hello("Everybody")
```
#Developing Hello World
To install helloworld, along the tools you need to develop and run tests, run the following in your virtualenv:
```bash
$ pip install -e .[dev]
```
